package edu.nyu.scps.record;

import android.media.MediaPlayer;
import android.media.MediaRecorder;
import android.os.Bundle;
import android.os.Environment;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;

import java.io.File;
import java.io.IOException;

public class MainActivity extends AppCompatActivity {
    private static final String LOG_TAG = MainActivity.class.getName();
    private static String fileName;

    private MediaRecorder mediaRecorder = null;
    private MediaPlayer mediaPlayer = null;

    boolean willStartRecording = true; //True if the next click will start a recording.
    boolean willStartPlaying = true;   //True if the next click will start a playback.

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        File directory = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_MUSIC);
        fileName = directory.getAbsolutePath() + "/" + "audiorecordtest.3gp";

        Button recordButton = (Button)findViewById(R.id.record);
        Button playButton = (Button)findViewById(R.id.play);

        recordButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Button button = (Button) view;
                if (willStartRecording) {
                    button.setText(R.string.stop_recording);
                    //Start recording.
                    mediaRecorder = new MediaRecorder();
                    mediaRecorder.setAudioSource(MediaRecorder.AudioSource.MIC); //microphone
                    mediaRecorder.setOutputFormat(MediaRecorder.OutputFormat.THREE_GPP);
                    mediaRecorder.setOutputFile(fileName);
                    mediaRecorder.setAudioEncoder(MediaRecorder.AudioEncoder.AMR_NB); //narrow band
                    try {
                        mediaRecorder.prepare();
                    } catch (IOException iOException) {
                        Log.e(LOG_TAG, "prepare failed", iOException);
                    }
                    mediaRecorder.start();
                } else {
                    button.setText(R.string.start_recording);
                    //Stop recording.
                    mediaRecorder.stop();
                    mediaRecorder.release();
                    mediaRecorder = null;
                }
                willStartRecording = !willStartRecording;
            }
        });

        playButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Button button = (Button) view;
                if (willStartPlaying) {
                    button.setText(R.string.stop_playing);
                    //Start playing.
                    mediaPlayer = new MediaPlayer();
                    try {
                        mediaPlayer.setDataSource(fileName);
                        mediaPlayer.prepare();
                    } catch (IOException iOException) {
                        Log.e(LOG_TAG, "setDataSource or prepare failed:", iOException);
                    }
                    mediaPlayer.start();
                } else {
                    button.setText(R.string.start_playing);
                    //Stop playing.
                    mediaPlayer.release();
                    mediaPlayer = null;
                }
                willStartPlaying = !willStartPlaying;
            }
        });
    }

    @Override
    public void onPause() {
        super.onPause();
        if (mediaRecorder != null) {
            mediaRecorder.release();
            mediaRecorder = null;
        }

        if (mediaPlayer != null) {
            mediaPlayer.release();
            mediaPlayer = null;
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }
}
